ShapError

Enum ShapError 

pub enum ShapError {
Show 16 variants DimensionMismatch { expected: String, found: String, }, InvalidFeatureIndex { index: usize, n_features: usize, }, InvalidSampleIndex { index: usize, n_samples: usize, }, InvalidOutputIndex { index: usize, n_outputs: usize, }, EmptyData, EmptyBackground, InvalidConfiguration(String), ModelError(String), MaskerError(String), NumericalError(String), SolverError(String), Unsupported(String), AdditivityError { expected: f64, actual: f64, difference: f64, tolerance: f64, }, MissingMetadata(String), OutputDimensionMismatch { expected: usize, found: usize, }, Other(String),
}
Errors that can occur while constructing or evaluating SHAP explainers.

Variants



DimensionMismatch

Two or more arrays have incompatible dimensions.

Fields

expected: String
found: String


InvalidFeatureIndex

A feature index is outside the valid feature range.

Fields

index: usize
n_features: usize


InvalidSampleIndex

A sample index is outside the valid sample range.

Fields

index: usize
n_samples: usize


InvalidOutputIndex

An output index is outside the valid model-output range.

Fields

index: usize
n_outputs: usize


EmptyData

The supplied data contains no samples.



EmptyBackground

The supplied background dataset contains no samples.



InvalidConfiguration(String)

An invalid configuration was supplied to an explainer or component.



ModelError(String)

A model prediction failed.



MaskerError(String)

A masking operation failed.



NumericalError(String)

A numerical operation failed.



SolverError(String)

A linear-system or weighted least-squares solver failed.



Unsupported(String)

The requested functionality is not supported.



AdditivityError

An explanation failed the SHAP additivity check.

Fields

expected: f64
actual: f64
difference: f64
tolerance: f64


MissingMetadata(String)

A required feature name or other metadata item was missing.



OutputDimensionMismatch

An operation was requested with incompatible output dimensions.

Fields

expected: usize
found: usize


Other(String)

An underlying error that does not have a more specific SHAP error type.