AutoExplainer

Struct AutoExplainer 

pub struct AutoExplainer<M, K = IndependentMasker> { /* private fields */ }
Automatic model-agnostic explainer selection with one shared configuration.

Exact SHAP is selected when the masker feature count is at most exact_threshold; otherwise Kernel SHAP is used. Native tree and linear models should still use their specialized explainers directly.

Implementations

Source

impl<M> AutoExplainer<M, IndependentMasker>

pub fn new(model: M, background: Background) -> Self

Source

impl<M, K> AutoExplainer<M, K>

pub fn from_masker(model: M, masker: K) -> Self

pub fn with_exact_threshold(self, features: usize) -> Self

pub fn with_kernel_samples(self, samples: usize) -> Self

pub fn with_seed(self, seed: u64) -> Self

pub fn with_ridge(self, ridge: f64) -> Self

pub fn with_evaluation_config(self, evaluation: EvaluationConfig) -> Self

Source

impl<M, K: Masker> AutoExplainer<M, K>