pub struct DeepExplainer<M> { /* private fields */ }Expand description
Deep SHAP coordinator for framework adapters implementing multiplier propagation through their native computation graph.
Implementations
Sourceimpl<M> DeepExplainer<M>
impl<M> DeepExplainer<M>
pub fn new(model: M, background: Background) -> Self
pub fn with_additivity_check(self, enabled: bool) -> Self
pub fn with_tolerance(self, t: f64) -> Self
Sourcepub fn with_batch_size(self, batch_size: usize) -> Self
pub fn with_batch_size(self, batch_size: usize) -> Self
Limits explained samples submitted to the graph adapter in one call.