pub struct GradientExplainer<M> { /* private fields */ }Expand description
Expected Gradients (Gradient SHAP) with background interpolation and optional Gaussian local smoothing.
Implementations
Sourceimpl<M> GradientExplainer<M>
impl<M> GradientExplainer<M>
pub fn new(model: M, background: Background) -> Self
pub fn with_nsamples(self, n: usize) -> Self
pub fn with_seed(self, s: u64) -> Self
pub fn with_local_smoothing(self, s: f64) -> Self
Sourcepub fn with_batch_size(self, batch_size: usize) -> Self
pub fn with_batch_size(self, batch_size: usize) -> Self
Limits gradient rows submitted to the autodiff backend in one call.
Sourceimpl<M: DifferentiablePredict> GradientExplainer<M>
impl<M: DifferentiablePredict> GradientExplainer<M>
Sourcepub fn explain_with_uncertainty(
&self,
x: ArrayView2<'_, f64>,
repeats: usize,
) -> Result<UncertainExplanation>
pub fn explain_with_uncertainty( &self, x: ArrayView2<'_, f64>, repeats: usize, ) -> Result<UncertainExplanation>
Repeats Expected Gradients with independent deterministic seeds and returns the standard error of the mean attribution.